/*_############################################################################
  _## 
  _##  SNMP4J-AgentJMX - JMXMutableTableSupport.java  
  _## 
  _##  Copyright (C) 2006-2009  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.agent.mo.jmx;

import org.snmp4j.smi.OID;
import org.snmp4j.agent.mo.MOTableRow;

/**
 * The <code>JMXMutableTableSupport</code> defines the necessary interface to
 * map tabular JMX data to a SNMP4J-Agent mutable table model. The interface
 * takes care of mapping JMX row identifiers to SNMP table indexes and vice
 * versa.
 *
 * @author Frank Fock
 * @version 1.0
 */
public interface JMXMutableTableSupport extends JMXTableSupport {

  /**
   * Sets the values of a SNMP row to the corresponding JMX structure.
   * @param tableOID
   *    the OID of the SNMP table.
   * @param row
   *    the SNMP table row.
   * @return
   *    a SNMP error status that indicates whether to operation succeeded or
   *    not.
   */
  int setRow(OID tableOID, MOTableRow row);

  /**
   * Creates a JMX structure that corresponds to the specified SNMP row.
   * @param tableOID
   *    the OID of the SNMP table.
   * @param row
   *    the SNMP table row to be created.
   * @return
   *    a SNMP error status that indicates whether to operation succeeded or
   *    not.
   */
  int createRow(OID tableOID, MOTableRow row);

  /**
   * Removes a JMX structure that corresponds to the specified SNMP row.
   * @param tableOID
   *    the OID of the SNMP table.
   * @param rowIndex
   *    the SNMP table row index of the row to be deleted.
   * @return
   *    a SNMP error status that indicates whether to operation succeeded or
   *    not.
   */
  int removeRow(OID tableOID, OID rowIndex);

  /**
   * Remove all rows (thus all JMX structures) corresponding to the specified
   * SNMP table.
   * @param tableOID
   *    the OID of the SNMP table.
   */
  void clear(OID tableOID);
}
